==> taomu-job-server-0.0.17-sources.jar: cool/taomu/box/job/server/controller/IndexController.java <==
/**
 * Copyright (c) 2023 murenchao
 * taomu is licensed under Mulan PubL v2.
 * You can use this software according to the terms and conditions of the Mulan PubL v2.
 * You may obtain a copy of Mulan PubL v2 at:
 *       http://license.coscl.org.cn/MulanPubL-2.0
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PubL v2 for more details.
 */
package cool.taomu.box.job.server.controller;

import cool.taomu.box.job.server.controller.entity.LoginEntity;
import cool.taomu.box.job.server.dao.TaskDao;
import java.io.File;
import java.util.HashMap;
import java.util.Map;
import javax.inject.Inject;
import javax.inject.Named;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import org.apache.commons.io.FileUtils;
import org.eclipse.xtext.xbase.lib.Exceptions;
import org.glassfish.jersey.server.mvc.ErrorTemplate;
import org.glassfish.jersey.server.mvc.Template;

@Path("job")
@SuppressWarnings("all")
public class IndexController {
  @Inject
  private TaskDao dao;
  
  @Inject
  @Named("taomubox.title")
  private String title;
  
  @GET
  @Path("/{page}")
  @ErrorTemplate(name = "/error.ftl")
  @Template(name = "/main.ftl")
  @Produces(MediaType.TEXT_HTML)
  public Map<String, String> page(@PathParam("page") final String page) {
    try {
      HashMap<String, String> pcmap = new HashMap<String, String>();
      pcmap.put("title", this.title);
      File _file = new File((("./template/" + page) + ".html"));
      pcmap.put("content", FileUtils.readFileToString(_file, "UTF-8"));
      File _file_1 = new File("./template/menu.html");
      pcmap.put("menu", FileUtils.readFileToString(_file_1, "UTF-8"));
      File _file_2 = new File("./template/navbar.html");
      pcmap.put("navbar", FileUtils.readFileToString(_file_2, "UTF-8"));
      return pcmap;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  @POST
  @Path("/login")
  @Produces(MediaType.APPLICATION_JSON)
  public Response login(final LoginEntity entity) {
    return null;
  }
  
  @GET
  @Path("/logout/{id}")
  @Produces(MediaType.APPLICATION_JSON)
  public Response logout(@PathParam("id") final String page) {
    return null;
  }
}

==> taomu-job-server-0.0.17.1-sources.jar: cool/taomu/box/job/server/controller/IndexController.java <==
/**
 * Copyright (c) 2023 murenchao
 * taomu is licensed under Mulan PubL v2.
 * You can use this software according to the terms and conditions of the Mulan PubL v2.
 * You may obtain a copy of Mulan PubL v2 at:
 *       http://license.coscl.org.cn/MulanPubL-2.0
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PubL v2 for more details.
 */
package cool.taomu.box.job.server.controller;

import cool.taomu.box.job.server.controller.entity.LoginEntity;
import cool.taomu.box.job.server.dao.TaskDao;
import java.io.File;
import java.util.HashMap;
import java.util.Map;
import javax.inject.Inject;
import javax.inject.Named;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import org.apache.commons.io.FileUtils;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.session.Session;
import org.apache.shiro.subject.Subject;
import org.eclipse.xtext.xbase.lib.Exceptions;
import org.glassfish.jersey.server.mvc.ErrorTemplate;
import org.glassfish.jersey.server.mvc.Template;

@Path("job")
@SuppressWarnings("all")
public class IndexController {
  @Inject
  private TaskDao dao;
  
  @Inject
  @Named("taomubox.title")
  private String title;
  
  @GET
  @Path("/{page}")
  @ErrorTemplate(name = "/error.ftl")
  @Template(name = "/main.ftl")
  @Produces(MediaType.TEXT_HTML)
  public Map<String, String> page(@PathParam("page") final String page) {
    try {
      HashMap<String, String> pcmap = new HashMap<String, String>();
      pcmap.put("title", this.title);
      File _file = new File((("./template/" + page) + ".html"));
      pcmap.put("content", FileUtils.readFileToString(_file, "UTF-8"));
      File _file_1 = new File("./template/menu.html");
      pcmap.put("menu", FileUtils.readFileToString(_file_1, "UTF-8"));
      File _file_2 = new File("./template/navbar.html");
      pcmap.put("navbar", FileUtils.readFileToString(_file_2, "UTF-8"));
      return pcmap;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  @POST
  @Path("/login")
  @Produces(MediaType.APPLICATION_JSON)
  public Response login(final LoginEntity entity) {
    Subject subject = SecurityUtils.getSubject();
    Session session = subject.getSession();
    session.setAttribute("someKey", "Hello World");
    return Response.status(304).build();
  }
  
  @GET
  @Path("/logout/{id}")
  @Produces(MediaType.APPLICATION_JSON)
  public Response logout(@PathParam("id") final String page) {
    return null;
  }
}
